==> react-gui-common-1.3.194.tgz: package/src/baseContainers/BaseService.js <==
import moment from 'moment';

export default class BaseService {
	// Initializing important variables
	constructor(domain) {
		if (domain !== null && domain !== undefined) {
			this.domain = domain;
		} else {
			this.domain = process.env.REACT_APP_BACKEND_URL; // API server domain
		}
		this.fetch = this.fetch.bind(this);
		this.getEnumList = this.getEnumList.bind(this);
		this.getEnumLabel = this.getEnumLabel.bind(this);
		this.setUiMethods = this.setUiMethods.bind(this);
		Date.prototype.toJSON = function() {
			return moment(this).format('YYYY-MM-DDTHH:mm:ssZ');
		};
		this.counter = 0;
	}

	setUiMethods(blockUi, unblockUi) {
		this.blockUi = blockUi;
		this.unblockUi = unblockUi;
	}

	fetch(url, options, headers) {
		const method = options !== undefined ? options.method : undefined;
		// performs api calls sending the required authentication headers
		if (headers === null || headers === undefined) {
			headers = {
				Accept: 'application/json',
				'Content-Type': 'application/json',
				'Cache-Control': 'no-cache, no-store, must-revalidate',
				Pragma: 'no-cahce',
			};
		}
		if (method === 'POST' || method === 'PUT') {
			this.counter += 1;
			if (this.blockUi !== undefined) {
				this.blockUi();
			}
		}
		return new Promise((resolve, reject) => {
			fetch(url, {
				headers,
				...options,
			})
				.then(this.parseJSON)
				.then(response => {
					if (method === 'POST' || method === 'PUT') {
						this.counter -= 1;
						if (this.counter <= 0 && this.unblockUi !== undefined) {
							this.unblockUi();
						}
					}
					if (response.ok) {
						return resolve(response.json);
					}
					// extract the error from the server's json
					return reject(response.json);
				})
				.catch(error => {
					if (method === 'POST' || method === 'PUT') {
						this.counter -= 1;
						if (this.counter <= 0 && this.unblockUi !== undefined) {
							this.unblockUi();
						}
					}
					if (
						error !== undefined &&
						error !== null &&
						error.message !== undefined &&
						error.message !== null &&
						(error.message.includes('NetworkError when attempting to fetch resource') ||
							error.message.includes('Failed to fetch'))
					) {
						error.message = 'komunikacji z serwerem podczas pobierania danych.';
					}
					reject(error);
				});
		});
	}

	parseJSON(response) {
		if (response.status) {
			return new Promise((resolve, reject) => {
				response.json().then(
					json => {
						resolve({
							status: response.status,
							ok: response.ok,
							json,
						});
					},
					reason => {
						console.log('reject:', reason);
						reject({
							status: response.status,
							ok: response.ok,
							json: { message: reason },
						});
					}
				);
			});
		} else {
			return new Promise(resolve =>
				resolve({
					status: response.status,
					ok: response.ok,
					json: { message: '' },
				})
			);
		}
	}

	objToQueryString(obj) {
		const keyValuePairs = [];
		for (const key in obj) {
			if (obj[key] !== null && obj[key] !== undefined) {
				keyValuePairs.push(`${encodeURIComponent(key)}=${encodeURIComponent(obj[key])}`);
			}
		}
		return (keyValuePairs.length > 0 ? '?' : '') + keyValuePairs.join('&');
	}

	getEnumList(enumName) {
		return this.fetch(`${this.domain}/${this.path}/enum-list/${enumName}`, {
			method: 'GET',
		}).then(res => {
			return Promise.resolve(res);
		});
	}

	getEnumLabel(enumName, enumValue) {
		return this.fetch(`${this.domain}/${this.path}/enum-label/${enumName}/${enumValue}`, {
			method: 'GET',
		}).then(res => {
			return Promise.resolve(res);
		});
	}
}

==> react-gui-common-1.3.222.tgz: package/src/baseContainers/BaseService.js <==
import moment from 'moment';

export default class BaseService {
	// Initializing important variables
	constructor(domain) {
		if (domain !== null && domain !== undefined) {
			this.domain = domain;
		} else {
			this.domain = process.env.REACT_APP_BACKEND_URL; // API server domain
		}
		this.fetch = this.fetch.bind(this);
		this.getEnumList = this.getEnumList.bind(this);
		this.getEnumLabel = this.getEnumLabel.bind(this);
		this.setUiMethods = this.setUiMethods.bind(this);
		Date.prototype.toJSON = function() {
			return moment(this).format('YYYY-MM-DDTHH:mm:ssZ');
		};
		this.counter = 0;
	}

	setUiMethods(blockUi, unblockUi) {
		this.blockUi = blockUi;
		this.unblockUi = unblockUi;
	}

	fetch(url, options, headers) {
		const method = options !== undefined ? options.method : undefined;
		// performs api calls sending the required authentication headers
		if (headers === null || headers === undefined) {
			headers = {
				Accept: 'application/json',
				'Content-Type': 'application/json',
				'Cache-Control': 'no-cache, no-store, must-revalidate',
				Pragma: 'no-cahce',
			};
		}
		if (method === 'POST' || method === 'PUT') {
			this.counter += 1;
			if (this.blockUi !== undefined) {
				this.blockUi();
			}
		}
		return new Promise((resolve, reject) => {
			fetch(url, {
				headers,
				...options,
			})
				.then(response => this.parseJSON(response, headers))
				.then(response => {
					if (method === 'POST' || method === 'PUT') {
						this.counter -= 1;
						if (this.counter <= 0 && this.unblockUi !== undefined) {
							this.unblockUi();
						}
					}
					if (response.ok && headers.accept === 'application/json') {
						return resolve(response.json);
					} else if (response.ok) {
						return resolve(response.body);
					}
					// extract the error from the server's json
					return reject(response.json);
				})
				.catch(error => {
					if (method === 'POST' || method === 'PUT') {
						this.counter -= 1;
						if (this.counter <= 0 && this.unblockUi !== undefined) {
							this.unblockUi();
						}
					}
					if (
						error !== undefined &&
						error !== null &&
						error.message !== undefined &&
						error.message !== null &&
						(error.message.includes('NetworkError when attempting to fetch resource') ||
							error.message.includes('Failed to fetch'))
					) {
						error.message = 'komunikacji z serwerem podczas pobierania danych.';
					}
					reject(error);
				});
		});
	}

	parseJSON(response, headers) {
		if (response.status) {
			return new Promise((resolve, reject) => {
				if (headers === undefined || headers.accept === 'application/json') {
					response.json().then(
						json => {
							resolve({
								status: response.status,
								ok: response.ok,
								json,
							});
						},
						reason => {
							console.log('reject:', reason);
							reject({
								status: response.status,
								ok: response.ok,
								json: { message: reason },
							});
						}
					);
				} else {
					resolve({
						status: response.status,
						ok: response.ok,
						body: response.body,
					});
				}
			});
		} else {
			return new Promise(resolve =>
				resolve({
					status: response.status,
					ok: response.ok,
					json: { message: '' },
				})
			);
		}
	}

	objToQueryString(obj) {
		const keyValuePairs = [];
		for (const key in obj) {
			if (obj[key] !== null && obj[key] !== undefined) {
				keyValuePairs.push(`${encodeURIComponent(key)}=${encodeURIComponent(obj[key])}`);
			}
		}
		return (keyValuePairs.length > 0 ? '?' : '') + keyValuePairs.join('&');
	}

	getEnumList(enumName) {
		return this.fetch(`${this.domain}/${this.path}/enum-list/${enumName}`, {
			method: 'GET',
		}).then(res => {
			return Promise.resolve(res);
		});
	}

	getEnumLabel(enumName, enumValue) {
		return this.fetch(`${this.domain}/${this.path}/enum-label/${enumName}/${enumValue}`, {
			method: 'GET',
		}).then(res => {
			return Promise.resolve(res);
		});
	}
}
